import { isString } from 'vuepress/shared';
import { convertToPinyin } from '@vuepress-reco/shared';
import { getNavLink, useThemeLocaleData } from '@composables/index.js';
import { useExtendPageData } from '@vuepress-reco/vuepress-plugin-page/composables';
function resolveNavbarItem(item) {
    if (isString(item)) {
        return getNavLink(item);
    }
    if ('children' in item && Array.isArray(item.children)) {
        return {
            ...item,
            children: item.children.map(resolveNavbarItem),
        };
    }
    return item;
}
export const useNavbarConfig = () => {
    const themeLocal = useThemeLocaleData();
    const { categorySummary } = useExtendPageData();
    const parseCategories = [
        {
            text: themeLocal.value.autoAddCategoryToNavbar?.categoryText || 'Categories',
            children: Object.values(categorySummary?.categories?.items || {}).map((c) => ({
                // @ts-ignore
                text: c.label,
                // @ts-ignore
                link: `/categories/${convertToPinyin(c.label)}/1.html`,
            }))
        },
        {
            text: themeLocal.value.autoAddCategoryToNavbar?.tagText || 'Tags',
            children: Object.values(categorySummary?.tags?.items || {}).map(t => ({
                // @ts-ignore
                text: t.label,
                // @ts-ignore
                link: `/tags/${convertToPinyin(t.label)}/1.html`,
            }))
        },
    ];
    let navItems = [...themeLocal.value.navbar || []];
    if (themeLocal.value.autoAddCategoryToNavbar) {
        navItems.splice(themeLocal.value.autoAddCategoryToNavbar?.location || 0, 0, ...parseCategories);
    }
    return navItems.map((item) => resolveNavbarItem(item));
};
